import { getCollection } from "astro:content";
import getSortedPosts from "@/utils/getSortedPosts";
import { SITE } from "@/config";

export async function GET() {
  const posts = await getCollection("blog");
  const sortedPosts = getSortedPosts(posts);

  // XML头部
  const xmlHeader = '<?xml version="1.0" encoding="UTF-8"?>';
  const urlsetStart = '<urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9">';
  const urlsetEnd = '</urlset>';

  // 生成URL条目
  const urlEntries = [
    // 主页
    `<url>
      <loc>${SITE.website}</loc>
      <changefreq>daily</changefreq>
      <priority>1.0</priority>
    </url>`,
    // 关于页面
    `<url>
      <loc>${SITE.website}about/</loc>
      <changefreq>monthly</changefreq>
      <priority>0.8</priority>
    </url>`,
    // 文章列表页
    `<url>
      <loc>${SITE.website}posts/</loc>
      <changefreq>daily</changefreq>
      <priority>0.8</priority>
    </url>`,
    // 标签页
    `<url>
      <loc>${SITE.website}tags/</loc>
      <changefreq>weekly</changefreq>
      <priority>0.7</priority>
    </url>`,
    // 搜索页
    `<url>
      <loc>${SITE.website}search/</loc>
      <changefreq>monthly</changefreq>
      <priority>0.6</priority>
    </url>`,
  ];

  // 添加所有文章URL
  sortedPosts.forEach(({ data, id }) => {
    const lastmod = data.modDatetime ?? data.pubDatetime;
    urlEntries.push(
      `<url>
        <loc>${SITE.website}posts/${id}/</loc>
        <lastmod>${new Date(lastmod).toISOString()}</lastmod>
        <changefreq>monthly</changefreq>
        <priority>0.7</priority>
      </url>`
    );
  });

  // 组合完整的XML
  const sitemap = [
    xmlHeader,
    urlsetStart,
    ...urlEntries,
    urlsetEnd
  ].join('\n');

  return new Response(sitemap, {
    headers: {
      'Content-Type': 'application/xml',
    },
  });
}